@@ -1,7 +1,7 @@
 /*
  * example.c -- Random example to test the flicksoup files
  *
- * Copyright (C) 2010-2012 Mario Sanchez Prada
+ * Copyright (C) 2010-2015 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -20,10 +20,18 @@
 
 #include <stdio.h>
 #include <glib.h>
+#include <errno.h>
+#include <gcrypt.h>
+#include <pthread.h>
 
+#include <config.h>
 #include <flicksoup/flicksoup.h>
 #include <libsoup/soup.h>
 
+#if GCRYPT_VERSION_NUMBER < 0x010600
+GCRY_THREAD_OPTION_PTHREAD_IMPL;
+#endif
+
 #define API_KEY "18861766601de84f0921ce6be729f925"
 #define SHARED_SECRET "6233fbefd85f733a"
 
@@ -44,6 +52,7 @@ void added_to_photoset_cb (GObject *object, GAsyncResult *res, gpointer unused);
 void photoset_created_cb (GObject *object, GAsyncResult *res, gpointer unused);
 void get_photosets_cb (GObject *object, GAsyncResult *res, gpointer unused);
 void photo_get_info_cb (GObject *object, GAsyncResult *res, gpointer unused);
+void set_date_posted_cb (GObject *object, GAsyncResult *res, gpointer user_data);
 void get_location_cb (GObject *object, GAsyncResult *res, gpointer unused);
 void set_location_cb (GObject *object, GAsyncResult *res, gpointer unused);
 void set_license_cb (GObject *object, GAsyncResult *res, gpointer unused);
@@ -372,6 +381,37 @@ photo_get_info_cb                       (GObject      *object,
     }
 }
 
+void
+set_date_posted_cb                      (GObject      *object,
+                                         GAsyncResult *res,
+                                         gpointer      user_data)
+{
+  FspSession *session = FSP_SESSION (object);
+  GError *error = NULL;
+  gboolean result = FALSE;
+
+  result = fsp_session_set_date_posted_finish (session, res, &error);
+  if (error != NULL)
+    {
+      g_print ("Error setting the date posted: %s\n", error->message);
+      g_error_free (error);
+    }
+  else
+    {
+      g_print ("[set_date_posted_cb]::Success! (%s)\n\n",
+               result ? "OK" : "FAIL");
+
+      /* Make a pause before continuing */
+      g_print ("Press ENTER to continue...\n\n");
+      getchar ();
+
+      /* Continue getting info about the picture */
+      g_print ("Getting info for photo %s...\n", uploaded_photo_id);
+      fsp_session_get_info (session, uploaded_photo_id, NULL,
+                            photo_get_info_cb, NULL);
+    }
+}
+
 void
 get_location_cb                         (GObject      *object,
                                          GAsyncResult *res,
@@ -389,6 +429,10 @@ get_location_cb                         (GObject      *object,
     }
   else
     {
+      GDateTime *date_now = NULL;
+      GDateTime *date = NULL;
+      gchar* date_str = NULL;
+
       g_print ("[get_location_cb]::Success! Location got:\n");
       g_print ("[get_location_cb]::\tLatitude: %g\n", location->latitude);
       g_print ("[get_location_cb]::\tLongitude: %g\n", location->longitude);
@@ -398,15 +442,23 @@ get_location_cb                         (GObject      *object,
       g_print ("Press ENTER to continue...\n\n");
       getchar ();
 
-      /* Continue getting info about the picture */
-      g_print ("Getting info for photo %s...\n", uploaded_photo_id);
-      fsp_session_get_info (session, uploaded_photo_id, NULL,
-                            photo_get_info_cb, NULL);
+      /* Continue setting the date posted to one year ago */
+      date_now = g_date_time_new_now_local ();
+      date = g_date_time_add_years (date_now, -1);
+      date_str = g_date_time_format (date, "%Y-%m-%d %H:%M:%S");
+      g_print ("Setting date posted for photo %s to %s...\n", uploaded_photo_id, date_str);
+      fsp_session_set_date_posted (session, uploaded_photo_id, date, NULL,
+                                   set_date_posted_cb, NULL);
+
+      g_free (date_str);
+      g_date_time_unref (date);
+      g_date_time_unref (date_now);
 
       fsp_data_free (FSP_DATA (location));
     }
 }
 
+
 void
 set_location_cb                         (GObject      *object,
                                          GAsyncResult *res,
@@ -727,6 +779,20 @@ main                                    (int    argc,
 
   g_print ("Running flicksoup example...\n\n");
 
+#if GCRYPT_VERSION_NUMBER < 0x010600
+  /* Initialize gcrypt at the very beginning */
+  gcry_control (GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread);
+#endif
+
+  /* Version check should be almost the very first call because it
+     makes sure that important subsystems are initialized. */
+  g_assert (gcry_check_version (LIBGCRYPT_MIN_VERSION));
+  /* Allocate a pool of 16k secure memory.  This make the secure
+     memory available and also drops privileges where needed. */
+  gcry_control (GCRYCTL_INIT_SECMEM, 16384, 0);
+  /* Tell Libgcrypt that initialization has completed. */
+  gcry_control (GCRYCTL_INITIALIZATION_FINISHED, 0);
+
   /* Find full path to the testing photo */
   test_photo_path = g_strdup_printf ("file://%s/%s",
                                      g_get_current_dir (),
